@@ -5,6 +5,8 @@ use warnings;
 
 use Dancer::Config 'setting';
 use Getopt::Long;
+use FindBin;
+use File::Spec;
 
 my $options = {
     port        => setting('port'),
@@ -26,6 +28,7 @@ sub process_args {
         'daemon'        => sub { arg_to_setting(@_) },
         'environment=s' => sub { arg_to_setting(@_) },
         'confdir=s'     => sub { arg_to_setting(@_) },
+        'restart=s'     => sub { arg_to_setting( auto_reload => $_[1] ) },
     ) || usage_and_exit();
 
     usage_and_exit() if $help;
@@ -34,14 +37,16 @@ sub process_args {
 sub usage_and_exit { print_usage() && exit(0) }
 
 sub print_usage {
+    my $app = File::Spec->catfile( $FindBin::RealBin, $FindBin::RealScript );
     print <<EOF
-\$ ./yourdancerapp.pl [options]
+\$ $app [options]
 
  Options:
    --daemon             Run in background (false)
    --port=XXXX          Port number to bind to (3000)
    --confdir=PATH       Path the config dir (appdir if not specified)
-   --environment=ENV    Environement to use (development)
+   --environment=ENV    Environment to use (development)
+   --restart=1|0        Should we restart the application between each request
    --help               Display usage information
 
 OPTIONS
@@ -70,7 +75,13 @@ If not specified, confdir points to appdir.
 
 --environment=ENV
 
-THIS OPTIONS IS NOT SUPPORTED YET 
+Which environment to use. By default this value is set to development.
+
+--restart
+
+Set the value of the B<auto_reload> setting. Useful when you want to switch
+this setting for a test without changing the value in your configurations
+file.
 
 EOF
 }
