@@ -4,10 +4,10 @@ use warnings;
 use Carp;
 use base 'Dancer::Logger::Abstract';
 
-use File::Temp qw/tempdir/;
 use Dancer::Config 'setting';
 use Dancer::FileUtils qw(open_file);
 use IO::File;
+use Fcntl qw(:flock SEEK_END);
 
 sub logdir {
     my $altpath = setting('log_path');
@@ -20,14 +20,12 @@ sub logdir {
             carp "log directory $logroot doesn't exist, am unable to create it";
             return;
         }
-    } else {
-        unless($logroot = tempdir(CLEANUP => 1, TMPDIR => 1)) {
-            carp "cannot create temp log directory";
-            return;
-        }
     }
 
-    my $expected_path = Dancer::FileUtils::path_no_verify($logroot, 'logs');
+    my $expected_path = $logroot                                  ?
+                        Dancer::FileUtils::path($logroot, 'logs') :
+                        Dancer::FileUtils::path('logs');
+
     return $expected_path if (-d $expected_path && -x _ && -w _);
 
     unless (-w $logroot and -x _) {
@@ -69,8 +67,15 @@ sub _log {
 
     return unless(ref $fh && $fh->opened);
 
+    flock($fh, LOCK_EX)
+        or carp "locking logfile $self->{logfile} failed";
+    seek($fh, 0, SEEK_END)
+        or carp "seeking to logfile $self->{logfile} end failed";
     $fh->print($self->format_message($level => $message))
         or carp "writing to logfile $self->{logfile} failed";
+    flock($fh, LOCK_UN)
+        or carp "unlocking logfile $self->{logfile} failed";
+
 }
 
 1;
@@ -98,8 +103,8 @@ file.
 
 =head2 logdir
 
-Returns the log directory, decided by "logs" either in "appdir" setting or in a
-temp directory. It's also possible to specify a logs directory with the log_path option.
+Returns the log directory, decided by "logs" either in "appdir" setting.
+It's also possible to specify a logs directory with the log_path option.
 
   setting log_path => $dir;
 
