@@ -95,12 +95,8 @@ sub halt {
         Dancer::SharedData->response($content);
     }
     else {
-        # This also sets the Response as the current one (SharedData)
-        Dancer::Response->new(
-            status => ($self->status || 200),
-            content => $content,
-            halted => 1,
-        );
+        $self->content($content) if defined $content;
+        $self->{halted} = 1;
     }
 }
 
